#!/bin/bash
#
# Copyright (c) Daniel Sheffield 2021
#
# All rights reserved
#
# THIS SOFTWARE IS PROVIDED AS IS WITHOUT WARRANTY
set -euo pipefail
ENDKW=ROLLBACK
DATE="$(date +%Y-%m-%d)"
STORE=" IS NOT NULL"
while getopts ":crd:s:" options; do
  case "${options}" in         
    c)                          
      ENDKW=COMMIT               
      ;;
    r)
      ENDKW=ROLLBACK
      ;;
    d)
      DATE="${OPTARG}"
      ;;
    s)
      STORE=" = \$store\$${OPTARG}\$store\$"
      ;;
    :)             
      ;;
    *) 
      usage 1>&2
      ;;
  esac
done

usage(){
    cat <<EOF
Usage: ./${0##*/} DATE STORE [ ROLLBACK | COMMIT ]
 
Companion script for grocery_transactions.py

Reads transactions from stdin.
ROLLBACK enabled by default

Example:
    # load generated transactions with ROLLBACK
    ./${0##*/} < transactions.txn
    ./${0##*/} ROLLBACK < transactions.txn
    
    # load generated transactions with COMMIT
    ./${0##*/} COMMIT < transactions.txn
EOF
}
if [[ -t 0 ]]
then
    usage 1>&2
    exit 1
fi
psql -d das <<EOF
BEGIN;
$(cat - )
SELECT
  date_part('day',ts)||'/'||date_part('month',ts)||' '||date_part('hour',ts)::int%12 AS ts,
  substr(store,1,4) AS shop,
  substr(description,1,32) AS description,
  quantity AS volume,
  substr(unit,1,4) AS unit,
  price,
  TRUNC(price/quantity,4) AS "\$/unit",
  sum(transaction_view.price) OVER (PARTITION BY transaction_view.ts::date ORDER BY transaction_view.ts, transaction_view.description ROWS BETWEEN UNBOUNDED PRECEDING AND CURRENT ROW) AS total,
  substr(product,1,10) AS product, substr(category,1,8) AS category, substr("group",1,9) AS "group", organic AS og
FROM transaction_view
WHERE ts BETWEEN '${DATE}'::date AND '${DATE}'::date + '23 hours 59 minutes 59 seconds'::interval
  AND store ${STORE};
${ENDKW};
EOF
